@@ -11,7 +11,7 @@ import warnings
 from functools import lru_cache, partial
 from math import floor
 
-from polyglot.builtins import codepoint_to_chr, hasenv, native_string_type
+from polyglot.builtins import hasenv
 
 if not hasenv('CALIBRE_SHOW_DEPRECATION_WARNINGS'):
     warnings.simplefilter('ignore', DeprecationWarning)
@@ -126,7 +126,7 @@ def confirm_config_name(name):
 
 
 _filename_sanitize_unicode = frozenset(('\\', '|', '?', '*', '<',        # no2to3
-    '"', ':', '>', '+', '/') + tuple(map(codepoint_to_chr, range(32))))  # no2to3
+    '"', ':', '>', '+', '/') + tuple(map(chr, range(32))))  # no2to3
 
 
 def sanitize_file_name(name, substitute='_'):
@@ -228,7 +228,7 @@ def extract(path, dir):
 
 
 def get_proxies(debug=True):
-    from polyglot.urllib import getproxies
+    from urllib.request import getproxies
     proxies = getproxies()
     for key, proxy in list(proxies.items()):
         if not proxy or '..' in proxy or key == 'auto':
@@ -289,7 +289,7 @@ def get_proxy_info(proxy_scheme, proxy_string):
     is not available in the string. If an exception occurs parsing the string
     this method returns None.
     '''
-    from polyglot.urllib import urlparse
+    from urllib.parse import urlparse
     try:
         proxy_url = f'{proxy_scheme}://{proxy_string}'
         urlinfo = urlparse(proxy_url)
@@ -492,23 +492,13 @@ def entity_regex():
 
 
 def replace_entities(raw, encoding=None):
-    if encoding is None:
-        try:
-            from calibre_extensions.fast_html_entities import replace_all_entities
-            replace_all_entities(raw)
-        except ImportError:  # Running from source without updated binaries
-            pass
-    return entity_regex().sub(partial(entity_to_unicode, encoding=encoding), raw)
+    from calibre_extensions.fast_html_entities import replace_all_entities
+    return replace_all_entities(raw)
 
 
 def xml_replace_entities(raw, encoding=None):
-    if encoding is None:
-        try:
-            from calibre_extensions.fast_html_entities import replace_all_entities
-            replace_all_entities(raw, True)
-        except ImportError:  # Running from source without updated binaries
-            pass
-    return entity_regex().sub(partial(xml_entity_to_unicode, encoding=encoding), raw)
+    from calibre_extensions.fast_html_entities import replace_all_entities
+    return replace_all_entities(raw, True)
 
 
 def prepare_string_for_xml(raw, attribute=False):
@@ -547,7 +537,7 @@ def as_unicode(obj, enc=preferred_encoding):
             obj = str(obj)
         except Exception:
             try:
-                obj = native_string_type(obj)
+                obj = str(obj)
             except Exception:
                 obj = repr(obj)
     return force_unicode(obj, enc=enc)
