@@ -35,7 +35,6 @@ from calibre.devices.interface import DevicePlugin
 from calibre.ebooks.metadata import MetaInformation
 from calibre.ebooks.metadata.sources.base import Source
 from calibre.utils.config import Config, ConfigProxy, OptionParser, make_config_dir, plugin_dir
-from polyglot.builtins import iteritems, itervalues
 
 builtin_names = frozenset(p.name for p in builtin_plugins)
 BLACKLISTED_PLUGINS = frozenset({
@@ -429,7 +428,7 @@ def reread_metadata_plugins():
         return order, plugin.name
 
     for group in (_metadata_readers, _metadata_writers):
-        for plugins in itervalues(group):
+        for plugins in group.values():
             if len(plugins) > 1:
                 plugins.sort(key=key)
 
@@ -732,7 +731,7 @@ def patch_metadata_plugins(possibly_updated_plugins):
                     # Metadata source plugins don't use initialize() but that
                     # might change in the future, so be safe.
                     patches[i].initialize()
-    for i, pup in iteritems(patches):
+    for i, pup in patches.items():
         _initialized_plugins[i] = pup
 # }}}
 
