@@ -15,7 +15,6 @@ from calibre.utils.date import UNDEFINED_DATE, is_date_undefined, isoformat, par
 from calibre.utils.icu import lower as icu_lower
 from calibre.utils.icu import strcmp
 from calibre.utils.localization import canonicalize_lang
-from polyglot.builtins import iteritems, itervalues
 
 missing = object()
 
@@ -131,7 +130,7 @@ def adapt_identifiers(to_tuple, x):
     if not isinstance(x, dict):
         x = dict(y.partition(':')[0::2] for y in to_tuple(x))
     ans = {}
-    for k, v in iteritems(x):
+    for k, v in x.items():
         k, v = clean_identifier(k, v)
         if k and v:
             ans[k] = v
@@ -226,18 +225,18 @@ def one_one_in_other(book_id_val_map, db, field, *args):
     'Set a one-one field in the non-books table, like comments'
     # Ignore those items whose value is the same as the current value
     g = field.table.book_col_map.get
-    book_id_val_map = {k:v for k, v in iteritems(book_id_val_map) if v != g(k, missing)}
-    deleted = tuple((k,) for k, v in iteritems(book_id_val_map) if v is None)
+    book_id_val_map = {k:v for k, v in book_id_val_map.items() if v != g(k, missing)}
+    deleted = tuple((k,) for k, v in book_id_val_map.items() if v is None)
     if deleted:
         db.executemany('DELETE FROM {} WHERE book=?'.format(field.metadata['table']),
                         deleted)
         for book_id in deleted:
             field.table.book_col_map.pop(book_id[0], None)
-    updated = {k:v for k, v in iteritems(book_id_val_map) if v is not None}
+    updated = {k:v for k, v in book_id_val_map.items() if v is not None}
     if updated:
         db.executemany('INSERT OR REPLACE INTO {}(book,{}) VALUES (?,?)'.format(
             field.metadata['table'], field.metadata['column']),
-            ((k, sqlite_datetime(v)) for k, v in iteritems(updated)))
+            ((k, sqlite_datetime(v)) for k, v in updated.items()))
         field.table.book_col_map.update(updated)
     return set(book_id_val_map)
 
@@ -305,13 +304,12 @@ def get_db_id(val, db, m, table, kmap, rid_map, allow_case_change,
 
 def change_case(case_changes, dirtied, db, table, m, is_authors=False):
     if is_authors:
-        vals = ((val.replace(',', '|'), item_id) for item_id, val in
-                iteritems(case_changes))
+        vals = ((val.replace(',', '|'), item_id) for item_id, val in case_changes.items())
     else:
-        vals = ((val, item_id) for item_id, val in iteritems(case_changes))
+        vals = ((val, item_id) for item_id, val in case_changes.items())
     db.executemany(
         'UPDATE {} SET {}=? WHERE id=?'.format(m['table'], m['column']), vals)
-    for item_id, val in iteritems(case_changes):
+    for item_id, val in case_changes.items():
         table.id_map[item_id] = val
         dirtied.update(table.col_book_map[item_id])
         if is_authors:
@@ -327,14 +325,14 @@ def many_one(book_id_val_map, db, field, allow_case_change, *args):
 
     # Map values to db ids, including any new values
     kmap = safe_lower if dt in {'text', 'series'} else lambda x:x
-    rid_map = {kmap(item):item_id for item_id, item in iteritems(table.id_map)}
+    rid_map = {kmap(item):item_id for item_id, item in table.id_map.items()}
     if len(rid_map) != len(table.id_map):
         # table has some entries that differ only in case, fix it
         table.fix_case_duplicates(db)
-        rid_map = {kmap(item):item_id for item_id, item in iteritems(table.id_map)}
+        rid_map = {kmap(item):item_id for item_id, item in table.id_map.items()}
     val_map = {None:None}
     case_changes = {}
-    for val in itervalues(book_id_val_map):
+    for val in book_id_val_map.values():
         if val is not None:
             get_db_id(val, db, m, table, kmap, rid_map, allow_case_change,
                     case_changes, val_map)
@@ -342,17 +340,17 @@ def many_one(book_id_val_map, db, field, allow_case_change, *args):
     if case_changes:
         change_case(case_changes, dirtied, db, table, m)
 
-    book_id_item_id_map = {k:val_map[v] for k, v in iteritems(book_id_val_map)}
+    book_id_item_id_map = {k:val_map[v] for k, v in book_id_val_map.items()}
 
     # Ignore those items whose value is the same as the current value
-    book_id_item_id_map = {k:v for k, v in iteritems(book_id_item_id_map)
+    book_id_item_id_map = {k:v for k, v in book_id_item_id_map.items()
         if v != table.book_col_map.get(k, None)}
     dirtied |= set(book_id_item_id_map)
 
     # Update the book->col and col->book maps
     deleted = set()
     updated = {}
-    for book_id, item_id in iteritems(book_id_item_id_map):
+    for book_id, item_id in book_id_item_id_map.items():
         old_item_id = table.book_col_map.get(book_id, None)
         if old_item_id is not None:
             table.col_book_map[old_item_id].discard(book_id)
@@ -375,8 +373,7 @@ def many_one(book_id_val_map, db, field, allow_case_change, *args):
             'DELETE FROM {0} WHERE book=?; INSERT INTO {0}(book,{1}) VALUES(?, ?)'
         )
         db.executemany(sql.format(table.link_table, m['link_column']),
-            ((book_id, book_id, item_id) for book_id, item_id in
-                    iteritems(updated)))
+            ((book_id, book_id, item_id) for book_id, item_id in updated.items()))
 
     # Remove no longer used items
     remove = {item_id:item_val for item_id, item_val in table.id_map.items() if not table.col_book_map.get(item_id, False)}
@@ -414,15 +411,15 @@ def many_many(book_id_val_map, db, field, allow_case_change, *args):
 
     # Map values to db ids, including any new values
     kmap = safe_lower if dt == 'text' else lambda x:x
-    rid_map = {kmap(item):item_id for item_id, item in iteritems(table.id_map)}
+    rid_map = {kmap(item):item_id for item_id, item in table.id_map.items()}
     if len(rid_map) != len(table.id_map):
         # table has some entries that differ only in case, fix it
         table.fix_case_duplicates(db)
-        rid_map = {kmap(item):item_id for item_id, item in iteritems(table.id_map)}
+        rid_map = {kmap(item):item_id for item_id, item in table.id_map.items()}
     val_map = {}
     case_changes = {}
-    book_id_val_map = {k:uniq(vals, kmap) for k, vals in iteritems(book_id_val_map)}
-    for vals in itervalues(book_id_val_map):
+    book_id_val_map = {k:uniq(vals, kmap) for k, vals in book_id_val_map.items()}
+    for vals in book_id_val_map.values():
         for val in vals:
             get_db_id(val, db, m, table, kmap, rid_map, allow_case_change,
                       case_changes, val_map, is_authors=is_authors)
@@ -430,7 +427,7 @@ def many_many(book_id_val_map, db, field, allow_case_change, *args):
     if case_changes:
         change_case(case_changes, dirtied, db, table, m, is_authors=is_authors)
         if is_authors:
-            for item_id, val in iteritems(case_changes):
+            for item_id, val in case_changes.items():
                 for book_id in table.col_book_map[item_id]:
                     current_sort = field.db_author_sort_for_book(book_id)
                     new_sort = field.author_sort_for_book(book_id)
@@ -451,7 +448,7 @@ def many_many(book_id_val_map, db, field, allow_case_change, *args):
     # Update the book->col and col->book maps
     deleted = set()
     updated = {}
-    for book_id, item_ids in iteritems(book_id_item_id_map):
+    for book_id, item_ids in book_id_item_id_map.items():
         old_item_ids = table.book_col_map.get(book_id, None)
         if old_item_ids:
             for old_item_id in old_item_ids:
@@ -471,7 +468,7 @@ def many_many(book_id_val_map, db, field, allow_case_change, *args):
                             ((k,) for k in deleted))
     if updated:
         vals = (
-            (book_id, val) for book_id, vals in iteritems(updated)
+            (book_id, val) for book_id, vals in updated.items()
             for val in vals
         )
         db.executemany(f'DELETE FROM {table.link_table} WHERE book=?',
@@ -509,7 +506,7 @@ def identifiers(book_id_val_map, db, field, *args):  # {{{
 
     table = field.table
     updates = set()
-    for book_id, identifiers in iteritems(book_id_val_map):
+    for book_id, identifiers in book_id_val_map.items():
         if book_id not in table.book_col_map:
             table.book_col_map[book_id] = {}
         current_ids = table.book_col_map[book_id]
@@ -518,7 +515,7 @@ def identifiers(book_id_val_map, db, field, *args):  # {{{
             table.col_book_map.get(key, set()).discard(book_id)
             current_ids.pop(key, None)
         current_ids.update(identifiers)
-        for key, val in iteritems(identifiers):
+        for key, val in identifiers.items():
             if key not in table.col_book_map:
                 table.col_book_map[key] = set()
             table.col_book_map[key].add(book_id)
@@ -565,8 +562,7 @@ class Writer:
                 self.accept_vals = bool
 
     def set_books(self, book_id_val_map, db, allow_case_change=True):
-        book_id_val_map = {k:self.adapter(v) for k, v in
-                           iteritems(book_id_val_map) if self.accept_vals(v)}
+        book_id_val_map = {k:self.adapter(v) for k, v in book_id_val_map.items() if self.accept_vals(v)}
         if not book_id_val_map:
             return set()
         dirtied = self.set_books_func(book_id_val_map, db, self.field,
@@ -576,7 +572,7 @@ class Writer:
     def set_books_for_enum(self, book_id_val_map, db, field,
                            allow_case_change):
         allowed = set(field.metadata['display']['enum_values'])
-        book_id_val_map = {k:v for k, v in iteritems(book_id_val_map) if v is
+        book_id_val_map = {k:v for k, v in book_id_val_map.items() if v is
                            None or v in allowed}
         if not book_id_val_map:
             return set()
