@@ -18,7 +18,6 @@ from calibre.ebooks.conversion import ConversionUserFeedBack
 from calibre.utils.config import OptionParser
 from calibre.utils.localization import localize_user_manual_link
 from calibre.utils.logging import Log
-from polyglot.builtins import iteritems
 
 USAGE = '%prog ' + _('''\
 input_file output_file [options]
@@ -272,7 +271,7 @@ def add_pipeline_options(parser, plumber):
 
               ))
 
-    for group, (desc, options) in iteritems(groups):
+    for group, (desc, options) in groups.items():
         if group:
             group = OptionGroup(parser, group, desc)
             parser.add_option_group(group)
