@@ -6,7 +6,9 @@ __copyright__ = '2013, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import os
 from collections import defaultdict
+from queue import Empty, Queue
 from threading import Thread
+from urllib.parse import urlparse
 
 from calibre import browser
 from calibre.ebooks.oeb.base import OEB_DOCS, OEB_STYLES, XHTML_MIME, urlunquote
@@ -15,9 +17,6 @@ from calibre.ebooks.oeb.polish.cover import get_raster_cover_name
 from calibre.ebooks.oeb.polish.parsing import parse_html5
 from calibre.ebooks.oeb.polish.replace import remove_links_to
 from calibre.ebooks.oeb.polish.utils import OEB_FONTS, actual_case_for_name, corrected_case_for_name, guess_type
-from polyglot.builtins import iteritems, itervalues
-from polyglot.queue import Empty, Queue
-from polyglot.urllib import urlparse
 
 
 class BadLink(BaseError):
@@ -135,7 +134,7 @@ class UnreferencedDoc(UnreferencedResource):
 
     def __call__(self, container):
         from calibre.ebooks.oeb.base import OPF
-        rmap = {v:k for k, v in iteritems(container.manifest_id_map)}
+        rmap = {v:k for k, v in container.manifest_id_map.items()}
         if self.name in rmap:
             manifest_id = rmap[self.name]
         else:
@@ -167,7 +166,7 @@ class Unmanifested(BadLink):
         if self.file_action == 'remove':
             container.remove_item(self.name)
         else:
-            rmap = {v:k for k, v in iteritems(container.manifest_id_map)}
+            rmap = {v:k for k, v in container.manifest_id_map.items()}
             if self.name not in rmap:
                 container.add_name_to_manifest(self.name)
         return True
@@ -249,7 +248,7 @@ class MimetypeMismatch(BaseError):
 def check_mimetypes(container):
     errors = []
     a = errors.append
-    for name, mt in iteritems(container.mime_map):
+    for name, mt in container.mime_map.items():
         gt = container.guess_type(name)
         if mt != gt:
             if mt == 'application/oebps-page-map+xml' and name.lower().endswith('.xml'):
@@ -287,7 +286,7 @@ def check_link_destinations(container):
     dest_map = {}
     opf_type = guess_type('a.opf')
     ncx_type = guess_type('a.ncx')
-    for name, mt in iteritems(container.mime_map):
+    for name, mt in container.mime_map.items():
         if mt in OEB_DOCS:
             for a in container.parsed(name).xpath('//*[local-name()="a" and @href]'):
                 href = a.get('href')
@@ -317,7 +316,7 @@ def check_links(container):
         x = x.removeprefix('u')
         return x
 
-    for name, mt in iteritems(container.mime_map):
+    for name, mt in container.mime_map.items():
         if mt in OEB_DOCS or mt in OEB_STYLES or mt in xml_types:
             for href, lnum, col in container.iterlinks(name):
                 if not href:
@@ -373,7 +372,7 @@ def check_links(container):
     cover_name = container.guide_type_map.get('cover', None)
     nav_items = frozenset(container.manifest_items_with_property('nav'))
 
-    for name, mt in iteritems(container.mime_map):
+    for name, mt in container.mime_map.items():
         if mt in OEB_STYLES and name not in spine_styles:
             a(UnreferencedResource(name))
         elif mt in OEB_DOCS and name not in spine_docs and name not in nav_items:
@@ -386,7 +385,7 @@ def check_links(container):
             continue
         unreferenced.add(name)
 
-    manifest_names = set(itervalues(container.manifest_id_map))
+    manifest_names = set(container.manifest_id_map.values())
     for name in container.mime_map:
         if name not in manifest_names and not container.ok_to_be_unmanifested(name):
             a(Unmanifested(name, unreferenced=name in unreferenced))
@@ -408,7 +407,7 @@ def get_html_ids(raw_data):
 def check_external_links(container, progress_callback=(lambda num, total:None), check_anchors=True):
     progress_callback(0, 0)
     external_links = defaultdict(list)
-    for name, mt in iteritems(container.mime_map):
+    for name, mt in container.mime_map.items():
         if mt in OEB_DOCS or mt in OEB_STYLES:
             for href, lnum, col in container.iterlinks(name):
                 purl = urlparse(href)
@@ -418,7 +417,7 @@ def check_external_links(container, progress_callback=(lambda num, total:None),
         return []
     items = Queue()
     ans = []
-    for el in iteritems(external_links):
+    for el in external_links.items():
         items.put(el)
     progress_callback(0, len(external_links))
     done = []
