@@ -15,6 +15,7 @@ from collections import defaultdict
 from io import BytesIO
 from itertools import count
 from math import floor
+from urllib.parse import urlparse
 
 from css_parser import getUrls, replaceUrls
 
@@ -55,8 +56,6 @@ from calibre.utils.ipc.simple_worker import WorkerError, fork_job
 from calibre.utils.logging import default_log
 from calibre.utils.xml_parse import safe_xml_fromstring
 from calibre.utils.zipfile import ZipFile
-from polyglot.builtins import iteritems
-from polyglot.urllib import urlparse
 
 exists, join, relpath = os.path.exists, os.path.join, os.path.relpath
 OPF_NAMESPACES = {'opf':OPF2_NS, 'dc':DC11_NS}
@@ -687,7 +686,7 @@ class Container(ContainerBase):  # {{{
         for item in self.opf_xpath('//opf:manifest/opf:item[@href and @media-type]'):
             ans[item.get('media-type').lower()].append(self.href_to_name(
                 item.get('href'), self.opf_name))
-        return {mt:tuple(v) for mt, v in iteritems(ans)}
+        return {mt:tuple(v) for mt, v in ans.items()}
 
     def manifest_items_with_property(self, property_name):
         ' All manifest items that have the specified property '
@@ -705,7 +704,7 @@ class Container(ContainerBase):  # {{{
             predicate = predicate.__eq__
         elif hasattr(predicate, '__contains__'):
             predicate = predicate.__contains__
-        for mt, names in iteritems(self.manifest_type_map):
+        for mt, names in self.manifest_type_map.items():
             if predicate(mt):
                 yield from names
 
@@ -825,7 +824,7 @@ class Container(ContainerBase):  # {{{
         the form (name, linear). Will raise an error if one of the names is not
         present in the manifest. '''
         imap = self.manifest_id_map
-        imap = {name:item_id for item_id, name in iteritems(imap)}
+        imap = {name:item_id for item_id, name in imap.items()}
         items = [item for item, name, linear in self.spine_iter]
         tail, last_tail = (items[0].tail, items[-1].tail) if items else ('\n    ', '\n  ')
         for i in items:
@@ -1090,7 +1089,7 @@ class Container(ContainerBase):  # {{{
         if set(self.name_path_map) != set(other.name_path_map):
             return 'Set of files is not the same'
         mismatches = []
-        for name, path in iteritems(self.name_path_map):
+        for name, path in self.name_path_map.items():
             opath = other.name_path_map[name]
             with open(path, 'rb') as f1, open(opath, 'rb') as f2:
                 if f1.read() != f2.read():
@@ -1298,7 +1297,7 @@ class EpubContainer(Container):
 
     def read_raw_unique_identifier(self):
         package_id = raw_unique_identifier = idpf_key = None
-        for attrib, val in iteritems(self.opf.attrib):
+        for attrib, val in self.opf.attrib.items():
             if attrib.endswith('unique-identifier'):
                 package_id = val
                 break
@@ -1354,7 +1353,7 @@ class EpubContainer(Container):
                         self.log.exception('Failed to parse obfuscation key')
                     key = None
 
-        for font, alg in iteritems(fonts):
+        for font, alg in fonts.items():
             tkey = key if alg == ADOBE_OBFUSCATION else idpf_key
             if not tkey:
                 raise ObfuscationKeyMissing('Failed to find obfuscation key')
@@ -1389,7 +1388,7 @@ class EpubContainer(Container):
         if outpath is None:
             outpath = self.pathtoepub
         self.commit_epub(outpath)
-        for name, data in iteritems(restore_fonts):
+        for name, data in restore_fonts.items():
             with self.open(name, 'wb') as f:
                 f.write(data)
 
