@@ -27,7 +27,6 @@ from calibre.ebooks import unit_convert
 from calibre.ebooks.oeb.base import CSS_MIME, OEB_STYLES, SVG, XHTML, XHTML_NS, urlnormalize, xpath
 from calibre.ebooks.oeb.normalize_css import DEFAULTS, normalizers
 from calibre.utils.resources import get_path as P
-from polyglot.builtins import iteritems
 
 css_parser_log.setLevel(logging.WARN)
 
@@ -869,7 +868,7 @@ class Style:
             self._get('padding-right'), base=self.parent_width)
 
     def __str__(self):
-        items = sorted(iteritems(self._style))
+        items = sorted(self._style.items())
         return '; '.join(f'{key}: {val}' for key, val in items)
 
     def cssdict(self):
@@ -878,12 +877,12 @@ class Style:
     def pseudo_classes(self, filter_css):
         if filter_css:
             css = copy.deepcopy(self._pseudo_classes)
-            for psel, cssdict in iteritems(css):
+            for psel, cssdict in css.items():
                 for k in filter_css:
                     cssdict.pop(k, None)
         else:
             css = self._pseudo_classes
-        return {k:v for k, v in iteritems(css) if v}
+        return {k:v for k, v in css.items() if v}
 
     @property
     def is_hidden(self):
