@@ -5,6 +5,7 @@ __copyright__ = '2008, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import glob
 import os
+import queue
 import signal
 import sys
 import threading
@@ -90,8 +91,6 @@ from calibre.utils.localization import get_lang
 from calibre.utils.resources import get_image_path as I
 from calibre.utils.resources import get_path as P
 from calibre.utils.resources import user_dir
-from polyglot import queue
-from polyglot.builtins import iteritems, string_or_bytes
 
 del pqc, geometry_for_restore_as_dict
 NO_URL_FORMATTING = QUrl.UrlFormattingOption.None_
@@ -1487,7 +1486,7 @@ SanitizeLibraryPath = sanitize_env_vars  # For old plugins
 
 
 def open_url(qurl):
-    if isinstance(qurl, string_or_bytes):
+    if isinstance(qurl, (str, bytes)):
         qurl = QUrl(qurl)
     scheme = qurl.scheme().lower() or 'file'
     import fnmatch
@@ -1533,7 +1532,7 @@ def open_url(qurl):
 
 
 def safe_open_url(qurl):
-    if isinstance(qurl, string_or_bytes):
+    if isinstance(qurl, (str, bytes)):
         qurl = QUrl(qurl)
     if qurl.scheme() in ('', 'file'):
         path = qurl.toLocalFile()
@@ -1686,7 +1685,7 @@ if is_running_from_develop:
 
 def event_type_name(ev_or_etype):
     etype = ev_or_etype.type() if isinstance(ev_or_etype, QEvent) else ev_or_etype
-    for name, num in iteritems(vars(QEvent)):
+    for name, num in vars(QEvent).items():
         if num == etype:
             return name
     return 'UnknownEventType'
