@@ -7,6 +7,7 @@ __docformat__ = 'restructuredtext en'
 
 import os
 import sys
+from contextlib import suppress
 from datetime import datetime
 
 from qt.core import (
@@ -201,15 +202,27 @@ class StyledItemDelegate(QStyledItemDelegate):
     Set the flag ignore_kb_mods_on_edit before opening an editor if you don't
     want keyboard modifiers taken into account, for example when using Shift-Tab
     as a backtab when editing cells. This prevents opening dialogs by mistake.
-    See giu2.library.views.closeEditor() for an example.
+    See gui2.library.views.closeEditor() for an example.
     '''
     is_editable_with_tab = True  # sub-classes set to False is needed
     ignore_kb_mods_on_edit = False
 
     def createEditor(self, parent, option, index):
         e = self.create_editor(parent, option, index)
+        if e is not None and (book_id := index.data(Qt.ItemDataRole.UserRole)) and isinstance(book_id, int):
+            setattr(e, 'underlying_book_id', book_id)
         return e
 
+    def setModelData(self, editor, model, index):
+        # Refresh the index using the underlying book_id in case the book list
+        # was changed while the editor was open, for example, by auto add
+        if book_id := getattr(editor, 'underlying_book_id', 0):
+            if (db := getattr(model, 'db', None)) and callable(getattr(db, 'row', None)):
+                with suppress(Exception):
+                    row = db.row(book_id)
+                    index = model.index(row, index.column(), index.parent())
+        super().setModelData(editor, model, index)
+
     def setEditorData(self, editor, index):
         # This method exists because of the ignore_kb_mods_on_edit flag. The
         # flag is cleared after the editor data is set, in set_editor_data. It
