@@ -12,6 +12,7 @@ import os
 import time
 from io import BytesIO
 from operator import attrgetter
+from queue import Empty, Queue
 from threading import Event, Thread
 
 from qt.core import (
@@ -69,8 +70,6 @@ from calibre.utils.img import image_to_data, save_image
 from calibre.utils.ipc.simple_worker import WorkerError, fork_job
 from calibre.utils.logging import GUILog as Log
 from calibre.utils.resources import get_image_path as I
-from polyglot.builtins import iteritems, itervalues
-from polyglot.queue import Empty, Queue
 
 # }}}
 
@@ -524,7 +523,7 @@ class IdentifyWidget(QWidget):  # {{{
             parts.append('authors:'+authors_to_string(authors))
             simple_desc += _('Authors: %s ') % authors_to_string(authors)
         if identifiers:
-            x = ', '.join(f'{k}:{v}' for k, v in iteritems(identifiers))
+            x = ', '.join(f'{k}:{v}' for k, v in identifiers.items())
             parts.append(x)
             if 'isbn' in identifiers:
                 simple_desc += 'ISBN: {}'.format(identifiers['isbn'])
@@ -705,7 +704,7 @@ class CoversModel(QAbstractListModel):  # {{{
 
     def plugin_for_index(self, index):
         row = index.row() if hasattr(index, 'row') else index
-        for k, v in iteritems(self.plugin_map):
+        for k, v in self.plugin_map.items():
             if row in v:
                 return k
 
@@ -766,7 +765,7 @@ class CoversModel(QAbstractListModel):  # {{{
             if pmap.isNull():
                 return
             self.beginInsertRows(QModelIndex(), last_row, last_row)
-            for rows in itervalues(self.plugin_map):
+            for rows in self.plugin_map.values():
                 for i in range(len(rows)):
                     if rows[i] >= last_row:
                         rows[i] += 1
@@ -776,7 +775,7 @@ class CoversModel(QAbstractListModel):  # {{{
         else:
             # single cover plugin
             idx = None
-            for plugin, rows in iteritems(self.plugin_map):
+            for plugin, rows in self.plugin_map.items():
                 if plugin.name == plugin_name:
                     idx = rows[0]
                     break
