@@ -34,7 +34,7 @@ from calibre.gui2 import error_dialog, gprefs, question_dialog
 from calibre.gui2.dialogs.confirm_delete import confirm
 from calibre.gui2.widgets import ComboBoxWithHelp
 from calibre.utils.icu import sort_key
-from calibre.utils.localization import localize_user_manual_link, ngettext, pgettext
+from calibre.utils.localization import localize_user_manual_link, ngettext
 from calibre.utils.search_query_parser import ParseException
 
 
@@ -375,7 +375,7 @@ class SearchRestrictionMixin:
         self.addAction(self.current_search_action)
         self.keyboard.register_shortcut(
             'vl-from-current-search', _('Virtual library from current search'), description=_(
-                'Create a temporary Virtual library from the current search'), group=pgettext('search restriction group name', 'Miscellaneous'),
+                'Create a temporary Virtual library from the current search'), group=_('Virtual library'),
             default_keys=('Ctrl+*',), action=self.current_search_action)
 
         self.search_based_vl_name = None
