@@ -8,6 +8,7 @@ import subprocess
 import sys
 import tempfile
 from functools import partial, wraps
+from urllib.parse import urlparse
 
 from qt.core import (
     QApplication,
@@ -88,8 +89,7 @@ from calibre.utils.imghdr import identify
 from calibre.utils.ipc.launch import exe_path, macos_edit_book_bundle_path
 from calibre.utils.localization import ngettext
 from calibre.utils.tdir_in_cache import tdir_in_cache
-from polyglot.builtins import as_bytes, iteritems, itervalues, string_or_bytes
-from polyglot.urllib import urlparse
+from polyglot.builtins import as_bytes
 
 _diff_dialogs = []
 last_used_transform_rules = []
@@ -228,11 +228,11 @@ class Boss(QObject):
             dictionaries.initialize(force=True)  # Reread user dictionaries
         if p.toolbars_changed:
             self.gui.populate_toolbars()
-            for ed in itervalues(editors):
+            for ed in editors.values():
                 if hasattr(ed, 'populate_toolbars'):
                     ed.populate_toolbars()
         if orig_size != tprefs['toolbar_icon_size']:
-            for ed in itervalues(editors):
+            for ed in editors.values():
                 if hasattr(ed, 'bars'):
                     for bar in ed.bars:
                         bar.setIconSize(QSize(tprefs['toolbar_icon_size'], tprefs['toolbar_icon_size']))
@@ -243,12 +243,12 @@ class Boss(QObject):
             self.refresh_file_list()
             self.gui.preview.start_refresh_timer()
         if ret == QDialog.DialogCode.Accepted or p.dictionaries_changed:
-            for ed in itervalues(editors):
+            for ed in editors.values():
                 ed.apply_settings(dictionaries_changed=p.dictionaries_changed)
         if orig_spell != tprefs['inline_spell_check']:
             from calibre.gui2.tweak_book.editor.syntax.html import refresh_spell_check_status
             refresh_spell_check_status()
-            for ed in itervalues(editors):
+            for ed in editors.values():
                 try:
                     ed.editor.highlighter.rehighlight()
                 except AttributeError:
@@ -450,7 +450,7 @@ class Boss(QObject):
 
     def update_editors_from_container(self, container=None, names=None):
         c = container or current_container()
-        for name, ed in tuple(iteritems(editors)):
+        for name, ed in tuple(editors.items()):
             if c.has_name(name):
                 if names is None or name in names:
                     ed.replace_data(c.raw_data(name))
@@ -574,7 +574,7 @@ class Boss(QObject):
         if files:
             folder_map = get_recommended_folders(current_container(), files)
             files = {x:('/'.join((folder, os.path.basename(x))) if folder else os.path.basename(x))
-                     for x, folder in iteritems(folder_map)}
+                     for x, folder in folder_map.items()}
             self.add_savepoint(_('Before: Add files'))
             c = current_container()
             added_fonts = set()
@@ -850,7 +850,7 @@ class Boss(QObject):
                                 det_msg=job.traceback, show=True)
         self.gui.file_list.build(current_container())
         self.set_modified()
-        for oldname, newname in iteritems(name_map):
+        for oldname, newname in name_map.items():
             if oldname in editors:
                 editors[newname] = ed = editors.pop(oldname)
                 ed.change_document_name(newname)
@@ -859,7 +859,7 @@ class Boss(QObject):
                 self.gui.preview.current_name = newname
         self.apply_container_update_to_gui()
         if from_filelist:
-            self.gui.file_list.select_names(frozenset(itervalues(name_map)), current_name=name_map.get(from_filelist))
+            self.gui.file_list.select_names(frozenset(name_map.values()), current_name=name_map.get(from_filelist))
             self.gui.file_list.file_list.setFocus(Qt.FocusReason.PopupFocusReason)
 
     # }}}
@@ -1192,7 +1192,7 @@ class Boss(QObject):
         search = {'find': text, 'mode': 'normal', 'case_sensitive': True, 'direction': 'down'}
         pat = get_search_regex(search)
         searchable_names = set(self.gui.file_list.searchable_names['text'])
-        for name, ed in iteritems(editors):
+        for name, ed in editors.items():
             searchable_names.discard(name)
             if ed.find_text(pat, complete=True):
                 self.show_editor(name)
@@ -1227,7 +1227,7 @@ class Boss(QObject):
 
     def word_ignored(self, word, locale):
         if tprefs['inline_spell_check']:
-            for ed in itervalues(editors):
+            for ed in editors.values():
                 try:
                     ed.editor.recheck_word(word, locale)
                 except AttributeError:
@@ -1306,7 +1306,7 @@ class Boss(QObject):
         actions on the current container '''
         changed = False
         with BusyCursor():
-            for name, ed in iteritems(editors):
+            for name, ed in editors.items():
                 if not ed.is_synced_to_container:
                     self.commit_editor_to_container(name)
                     ed.is_synced_to_container = True
@@ -1317,7 +1317,7 @@ class Boss(QObject):
         ' Save the book. Saving is performed in the background '
         self.gui.update_window_title()
         c = current_container()
-        for name, ed in iteritems(editors):
+        for name, ed in editors.items():
             if ed.is_modified or not ed.is_synced_to_container:
                 self.commit_editor_to_container(name, c)
                 ed.is_modified = False
@@ -1367,7 +1367,7 @@ class Boss(QObject):
             path += '.' + ext.lower()
         tdir = self.mkdtemp(prefix='save-copy-')
         container = clone_container(c, tdir)
-        for name, ed in iteritems(editors):
+        for name, ed in editors.items():
             if ed.is_modified or not ed.is_synced_to_container:
                 self.commit_editor_to_container(name, container)
 
@@ -1565,7 +1565,7 @@ class Boss(QObject):
 
     @in_thread_job
     def export_requested(self, name_or_names, path):
-        if isinstance(name_or_names, string_or_bytes):
+        if isinstance(name_or_names, (str, bytes)):
             return self.export_file(name_or_names, path)
         for name in name_or_names:
             dest = os.path.abspath(os.path.join(path, name))
@@ -1628,7 +1628,7 @@ class Boss(QObject):
             self.commit_all_editors_to_container()
             name_map = json.loads(bytes(md.data(FILE_COPY_MIME)))
             container = current_container()
-            for name, (path, mt) in iteritems(name_map):
+            for name, (path, mt) in name_map.items():
                 with open(path, 'rb') as f:
                     container.add_file(name, f.read(), media_type=mt, modify_name_if_needed=True)
             self.apply_container_update_to_gui()
@@ -1848,7 +1848,7 @@ class Boss(QObject):
         if not self.ensure_book(_('No book is currently open. You must first open a book to edit.')):
             return
         c = current_container()
-        files = [name for name, mime in iteritems(c.mime_map) if c.exists(name) and syntax_from_mime(name, mime) is not None]
+        files = [name for name, mime in c.mime_map.items() if c.exists(name) and syntax_from_mime(name, mime) is not None]
         d = QuickOpen(files, parent=self.gui)
         if d.exec() == QDialog.DialogCode.Accepted and d.selected_result is not None:
             self.edit_file_requested(d.selected_result, None, c.mime_map[d.selected_result])
@@ -1888,7 +1888,7 @@ class Boss(QObject):
 
     def editor_data_changed(self, editor):
         self.gui.preview.start_refresh_timer()
-        for name, ed in iteritems(editors):
+        for name, ed in editors.items():
             if ed is editor:
                 self.gui.toc_view.start_refresh_timer(name)
                 break
@@ -2070,7 +2070,7 @@ class Boss(QObject):
                 order = [k for k in order[extra:] if k in mem]
                 mem = {k:mem[k] for k in order}
             mem[c.path_to_ebook] = {
-                'editors':{name:ed.current_editing_state for name, ed in iteritems(editors)},
+                'editors':{name:ed.current_editing_state for name, ed in editors.items()},
                 'currently_editing':self.currently_editing,
                 'tab_order':self.gui.central.tab_order,
             }
