@@ -39,7 +39,6 @@ from calibre.gui2 import error_dialog
 from calibre.gui2.tweak_book import tprefs
 from calibre.gui2.tweak_book.editor import syntax_text_char_format
 from calibre.gui2.tweak_book.widgets import Dialog
-from polyglot.builtins import iteritems
 
 underline_styles = {'single', 'dash', 'dot', 'dash_dot', 'dash_dot_dot', 'wave', 'spell'}
 
@@ -59,8 +58,8 @@ SLDX = {'base03':'1c1c1c', 'base02':'262626', 'base01':'585858', 'base00':'62626
 SLD  = {'base03':'002b36', 'base02':'073642', 'base01':'586e75', 'base00':'657b83', 'base0':'839496', 'base1':'93a1a1', 'base2':'eee8d5', 'base3':'fdf6e3', 'yellow':'b58900', 'orange':'cb4b16', 'red':'dc322f', 'magenta':'d33682', 'violet':'6c71c4', 'blue':'268bd2', 'cyan':'2aa198', 'green':'859900'}  # noqa: E501
 m = {f'base{n}':f'base{n:02}' for n in range(1, 4)}
 m.update({f'base{n:02}':f'base{n}' for n in range(1, 4)})
-SLL =  {m.get(k, k): v for k, v in iteritems(SLD)}
-SLLX = {m.get(k, k): v for k, v in iteritems(SLDX)}
+SLL =  {m.get(k, k): v for k, v in SLD.items()}
+SLLX = {m.get(k, k): v for k, v in SLDX.items()}
 SOLARIZED = \
     '''
     CursorLine   bg={base02}
@@ -259,7 +258,7 @@ def read_theme(raw):
     return ans
 
 
-THEMES = {k:read_theme(raw) for k, raw in iteritems(THEMES)}
+THEMES = {k:read_theme(raw) for k, raw in THEMES.items()}
 
 
 def u(x):
@@ -281,7 +280,7 @@ def to_highlight(data):
 
 def read_custom_theme(data):
     dt = THEMES[default_theme()].copy()
-    dt.update({k:to_highlight(v) for k, v in iteritems(data)})
+    dt.update({k:to_highlight(v) for k, v in data.items()})
     return dt
 
 
@@ -639,7 +638,7 @@ class ThemeEditor(Dialog):
             data.pop(k)
         for k in missing:
             data[k] = dict(THEMES[default_theme()][k]._asdict())
-            for nk, nv in iteritems(data[k]):
+            for nk, nv in data[k].items():
                 if isinstance(nv, QBrush):
                     data[k][nk] = str(nv.color().name())
         if extra or missing:
@@ -685,8 +684,8 @@ class ThemeEditor(Dialog):
             name = '*' + d.theme_name
             base = str(d.base.currentText())
             theme = {}
-            for key, val in iteritems(THEMES[base]):
-                theme[key] = {k:col_to_string(v.color()) if isinstance(v, QBrush) else v for k, v in iteritems(val._asdict())}
+            for key, val in THEMES[base].items():
+                theme[key] = {k:col_to_string(v.color()) if isinstance(v, QBrush) else v for k, v in val._asdict().items()}
             tprefs['custom_themes'][name] = theme
             tprefs['custom_themes'] = tprefs['custom_themes']
             t = self.theme
