@@ -6,7 +6,9 @@ __copyright__ = '2015, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import errno
 import hashlib
+import http.client
 import os
+import reprlib
 import struct
 import time
 import uuid
@@ -24,8 +26,7 @@ from calibre.srv.loop import WRITE
 from calibre.srv.utils import HTTP1, HTTP11, Cookie, MultiDict, get_translator_for_lang, http_date, socket_errors_socket_closed, sort_q_values
 from calibre.utils.monotonic import monotonic
 from calibre.utils.speedups import ReadOnlyFileBuffer
-from polyglot import http_client, reprlib
-from polyglot.builtins import error_message, iteritems, itervalues, reraise, string_or_bytes
+from polyglot.builtins import error_message, reraise
 
 Range = namedtuple('Range', 'start stop size')
 MULTIPART_SEPARATOR = uuid.uuid4().hex
@@ -232,7 +233,7 @@ class RequestData:  # {{{
         self.forwarded_for = forwarded_for
         self.request_original_uri = request_original_uri
         self.opts = opts
-        self.status_code = http_client.OK
+        self.status_code = http.client.OK
         self.outcookie = Cookie()
         self.lang_code = self.gettext_func = self.ngettext_func = None
         self.set_translator(self.get_preferred_language())
@@ -315,7 +316,7 @@ def filesystem_file_output(output, outheaders, stat_result):
     etag = getattr(output, 'etag', None)
     if etag is None:
         oname = output.name or ''
-        if not isinstance(oname, string_or_bytes):
+        if not isinstance(oname, (str, bytes)):
             oname = str(oname)
         etag = hashlib.sha1((str(stat_result.st_mtime) + force_unicode(oname)).encode('utf-8')).hexdigest()
     else:
@@ -409,16 +410,16 @@ class HTTPConnection(HTTPRequest):
         if self.response_protocol is HTTP1:
             # HTTP/1.0 has no 413/414/303 codes
             status_code = {
-                http_client.REQUEST_ENTITY_TOO_LARGE:http_client.BAD_REQUEST,
-                http_client.REQUEST_URI_TOO_LONG:http_client.BAD_REQUEST,
-                http_client.SEE_OTHER:http_client.FOUND
+                http.client.REQUEST_ENTITY_TOO_LARGE:http.client.BAD_REQUEST,
+                http.client.REQUEST_URI_TOO_LONG:http.client.BAD_REQUEST,
+                http.client.SEE_OTHER:http.client.FOUND
             }.get(status_code, status_code)
 
         self.close_after_response = close_after_response
         msg = msg.encode('utf-8')
         ct = 'http' if self.method == 'TRACE' else 'plain'
         buf = [
-            f'{self.response_protocol} {status_code} {http_client.responses[status_code]}',
+            f'{self.response_protocol} {status_code} {http.client.responses[status_code]}',
             f'Content-Length: {len(msg)}',
             f'Content-Type: text/{ct}; charset=UTF-8',
             'Date: ' + http_date(),
@@ -426,7 +427,7 @@ class HTTPConnection(HTTPRequest):
         if self.close_after_response and self.response_protocol is HTTP11:
             buf.append('Connection: close')
         if extra_headers is not None:
-            for h, v in iteritems(extra_headers):
+            for h, v in extra_headers.items():
                 buf.append(f'{h}: {v}')
         buf.append('')
         buf = [(x + '\r\n').encode('ascii') for x in buf]
@@ -439,7 +440,7 @@ class HTTPConnection(HTTPRequest):
     def prepare_response(self, inheaders, request_body_file):
         if self.method == 'TRACE':
             msg = force_unicode(self.request_line, 'utf-8') + '\n' + inheaders.pretty()
-            return self.simple_response(http_client.OK, msg, close_after_response=False)
+            return self.simple_response(http.client.OK, msg, close_after_response=False)
         request_body_file.seek(0)
         outheaders = MultiDict()
         data = RequestData(
@@ -456,28 +457,28 @@ class HTTPConnection(HTTPRequest):
 
     def send_range_not_satisfiable(self, content_length):
         buf = [
-            f'{self.response_protocol} {http_client.REQUESTED_RANGE_NOT_SATISFIABLE} {http_client.responses[http_client.REQUESTED_RANGE_NOT_SATISFIABLE]}',
+            f'{self.response_protocol} {http.client.REQUESTED_RANGE_NOT_SATISFIABLE} {http.client.responses[http.client.REQUESTED_RANGE_NOT_SATISFIABLE]}',
             'Date: ' + http_date(),
             f'Content-Range: bytes */{content_length}',
         ]
         response_data = header_list_to_file(buf)
-        self.log_access(status_code=http_client.REQUESTED_RANGE_NOT_SATISFIABLE, response_size=response_data.sz)
+        self.log_access(status_code=http.client.REQUESTED_RANGE_NOT_SATISFIABLE, response_size=response_data.sz)
         self.response_ready(response_data)
 
     def send_not_modified(self, etag=None):
         buf = [
-            f'{self.response_protocol} {http_client.NOT_MODIFIED} {http_client.responses[http_client.NOT_MODIFIED]}',
+            f'{self.response_protocol} {http.client.NOT_MODIFIED} {http.client.responses[http.client.NOT_MODIFIED]}',
             'Content-Length: 0',
             'Date: ' + http_date(),
         ]
         if etag is not None:
             buf.append('ETag: ' + etag)
         response_data = header_list_to_file(buf)
-        self.log_access(status_code=http_client.NOT_MODIFIED, response_size=response_data.sz)
+        self.log_access(status_code=http.client.NOT_MODIFIED, response_size=response_data.sz)
         self.response_ready(response_data)
 
     def report_busy(self):
-        self.simple_response(http_client.SERVICE_UNAVAILABLE)
+        self.simple_response(http.client.SERVICE_UNAVAILABLE)
 
     def job_done(self, ok, result):
         if not ok:
@@ -515,10 +516,10 @@ class HTTPConnection(HTTPRequest):
         if ct.startswith('text/') and 'charset=' not in ct:
             outheaders.set('Content-Type', ct + '; charset=UTF-8', replace_all=True)
 
-        buf = [HTTP11 + f' {data.status_code} ' + http_client.responses[data.status_code]]
-        for header, value in sorted(iteritems(outheaders), key=itemgetter(0)):
+        buf = [HTTP11 + f' {data.status_code} ' + http.client.responses[data.status_code]]
+        for header, value in sorted(outheaders.items(), key=itemgetter(0)):
             buf.append(f'{header}: {value}')
-        for morsel in itervalues(data.outcookie):
+        for morsel in data.outcookie.values():
             morsel['version'] = '1'
             x = morsel.output()
             if isinstance(x, bytes):
@@ -536,7 +537,7 @@ class HTTPConnection(HTTPRequest):
     def log_access(self, status_code, response_size=None, username=None):
         if self.access_log is None:
             return
-        if not self.opts.log_not_found and status_code == http_client.NOT_FOUND:
+        if not self.opts.log_not_found and status_code == http.client.NOT_FOUND:
             return
         ff = self.forwarded_for
         if ff:
@@ -632,7 +633,7 @@ class HTTPConnection(HTTPRequest):
         self.ready = ready
 
     def report_unhandled_exception(self, e, formatted_traceback):
-        self.simple_response(http_client.INTERNAL_SERVER_ERROR)
+        self.simple_response(http.client.INTERNAL_SERVER_ERROR)
 
     def finalize_output(self, output, request, is_http1):
         none_match = parse_if_none_match(request.inheaders.get('If-None-Match', ''))
@@ -642,7 +643,7 @@ class HTTPConnection(HTTPRequest):
                 if self.method in ('GET', 'HEAD'):
                     self.send_not_modified(output.etag)
                 else:
-                    self.simple_response(http_client.PRECONDITION_FAILED)
+                    self.simple_response(http.client.PRECONDITION_FAILED)
                 return
 
         opts = self.opts
@@ -652,7 +653,7 @@ class HTTPConnection(HTTPRequest):
             output = filesystem_file_output(output, outheaders, stat_result)
             if 'Content-Type' not in outheaders:
                 output_name = output.name
-                if not isinstance(output_name, string_or_bytes):
+                if not isinstance(output_name, (str, bytes)):
                     output_name = str(output_name)
                 mt = guess_type(output_name)[0]
                 if mt:
@@ -661,7 +662,7 @@ class HTTPConnection(HTTPRequest):
                     outheaders['Content-Type'] = mt
                 else:
                     outheaders['Content-Type'] = 'application/octet-stream'
-        elif isinstance(output, string_or_bytes):
+        elif isinstance(output, (str, bytes)):
             output = dynamic_output(output, outheaders)
         elif hasattr(output, 'read'):
             output = ReadableOutput(output)
@@ -673,10 +674,10 @@ class HTTPConnection(HTTPRequest):
             output = GeneratedOutput(output)
         ct = outheaders.get('Content-Type', '').partition(';')[0]
         compressible = (not ct or ct.startswith(('text/', 'image/svg')) or ct.partition(';')[0] in COMPRESSIBLE_TYPES)
-        compressible = (compressible and request.status_code == http_client.OK and
+        compressible = (compressible and request.status_code == http.client.OK and
                         (opts.compress_min_size > -1 and output.content_length >= opts.compress_min_size) and
                         acceptable_encoding(request.inheaders.get('Accept-Encoding', '')) and not is_http1)
-        accept_ranges = (not compressible and output.accept_ranges is not None and request.status_code == http_client.OK and
+        accept_ranges = (not compressible and output.accept_ranges is not None and request.status_code == http.client.OK and
                         not is_http1)
         ranges = get_ranges(request.inheaders.get('Range'), output.content_length) if output.accept_ranges and self.method in ('GET', 'HEAD') else None
         if_range = (request.inheaders.get('If-Range') or '').strip()
@@ -693,7 +694,7 @@ class HTTPConnection(HTTPRequest):
             if self.method in ('GET', 'HEAD'):
                 self.send_not_modified(output.etag)
             else:
-                self.simple_response(http_client.PRECONDITION_FAILED)
+                self.simple_response(http.client.PRECONDITION_FAILED)
             return
 
         output.ranges = None
@@ -725,7 +726,7 @@ class HTTPConnection(HTTPRequest):
                 outheaders.set('Content-Length', f'{size}', replace_all=True)
                 outheaders.set('Content-Type', 'multipart/byteranges; boundary=' + MULTIPART_SEPARATOR, replace_all=True)
                 output.ranges = zip_longest(ranges, range_parts)
-            request.status_code = http_client.PARTIAL_CONTENT
+            request.status_code = http.client.PARTIAL_CONTENT
         return output
 
 
