@@ -5,6 +5,7 @@ __license__ = 'GPL v3'
 __copyright__ = '2015, Kovid Goyal <kovid at kovidgoyal.net>'
 
 import hashlib
+import http.client
 import os
 import string
 import time
@@ -17,8 +18,6 @@ from calibre.srv.tests.base import BaseTest, TestServer
 from calibre.srv.utils import eintr_retry_call
 from calibre.utils.monotonic import monotonic
 from calibre.utils.resources import get_path as P
-from polyglot import http_client
-from polyglot.builtins import iteritems
 
 is_ci = os.environ.get('CI', '').lower() == 'true'
 
@@ -33,7 +32,7 @@ class TestHTTP(BaseTest):
             p = HTTPHeaderParser()
             p.push(*lines)
             self.assertTrue(p.finished)
-            self.assertSetEqual(set(p.hdict.items()), {(k.replace('_', '-').title(), v) for k, v in iteritems(kwargs)}, name + ' failed')
+            self.assertSetEqual(set(p.hdict.items()), {(k.replace('_', '-').title(), v) for k, v in kwargs.items()}, name + ' failed')
 
         test('Continuation line parsing',
              b'a: one',
@@ -106,7 +105,7 @@ class TestHTTP(BaseTest):
             def test(al, q):
                 conn.request('GET', '/', headers={'Accept-Language': al})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.OK)
+                self.ae(r.status, http.client.OK)
                 q += get_translator(q)[-1].gettext('Unknown')
                 self.ae(r.read(), q.encode('utf-8'))
 
@@ -156,7 +155,7 @@ class TestHTTP(BaseTest):
 
         def raw_send(conn, raw):
             conn.send(raw)
-            conn._HTTPConnection__state = http_client._CS_REQ_SENT
+            conn._HTTPConnection__state = http.client._CS_REQ_SENT
             return conn.getresponse()
 
         base_timeout = 0.5 if is_ci else 0.1
@@ -164,31 +163,31 @@ class TestHTTP(BaseTest):
         with TestServer(handler, timeout=base_timeout, max_header_line_size=100./1024, max_request_body_size=100./(1024*1024)) as server:
             conn = server.connect()
             r = raw_send(conn, b'hello\n')
-            self.ae(r.status, http_client.BAD_REQUEST)
+            self.ae(r.status, http.client.BAD_REQUEST)
             self.ae(r.read(), b'HTTP requires CRLF line terminators')
 
             r = raw_send(conn, b'\r\nGET /index.html HTTP/1.1\r\n\r\n')
-            self.ae(r.status, http_client.NOT_FOUND), self.ae(r.read(), b'Requested resource not found')
+            self.ae(r.status, http.client.NOT_FOUND), self.ae(r.read(), b'Requested resource not found')
 
             r = raw_send(conn, b'\r\n\r\nGET /index.html HTTP/1.1\r\n\r\n')
-            self.ae(r.status, http_client.BAD_REQUEST)
+            self.ae(r.status, http.client.BAD_REQUEST)
             self.ae(r.read(), b'Multiple leading empty lines not allowed')
 
             r = raw_send(conn, b'hello world\r\n')
-            self.ae(r.status, http_client.BAD_REQUEST)
+            self.ae(r.status, http.client.BAD_REQUEST)
             self.ae(r.read(), b'Malformed Request-Line')
 
             r = raw_send(conn, b'x' * 200)
-            self.ae(r.status, http_client.BAD_REQUEST)
+            self.ae(r.status, http.client.BAD_REQUEST)
             self.ae(r.read(), b'')
 
             r = raw_send(conn, b'XXX /index.html HTTP/1.1\r\n\r\n')
-            self.ae(r.status, http_client.BAD_REQUEST), self.ae(r.read(), b'Unknown HTTP method')
+            self.ae(r.status, http.client.BAD_REQUEST), self.ae(r.read(), b'Unknown HTTP method')
 
             # Test 404
             conn.request('HEAD', '/moose')
             r = conn.getresponse()
-            self.ae(r.status, http_client.NOT_FOUND)
+            self.ae(r.status, http.client.NOT_FOUND)
             self.assertIsNotNone(r.getheader('Date', None))
             self.ae(r.getheader('Content-Length'), str(len(body)))
             self.ae(r.getheader('Content-Type'), 'text/plain; charset=UTF-8')
@@ -196,7 +195,7 @@ class TestHTTP(BaseTest):
             self.ae(r.read(), b'')
             conn.request('GET', '/choose')
             r = conn.getresponse()
-            self.ae(r.status, http_client.NOT_FOUND)
+            self.ae(r.status, http.client.NOT_FOUND)
             self.ae(r.read(), b'Requested resource not found')
 
             # Test 500
@@ -204,7 +203,7 @@ class TestHTTP(BaseTest):
             conn = server.connect()
             conn.request('GET', '/test/')
             r = conn.getresponse()
-            self.ae(r.status, http_client.INTERNAL_SERVER_ERROR)
+            self.ae(r.status, http.client.INTERNAL_SERVER_ERROR)
 
             # Test 301
             def handler(data):
@@ -213,7 +212,7 @@ class TestHTTP(BaseTest):
             conn = server.connect()
             conn.request('GET', '/')
             r = conn.getresponse()
-            self.ae(r.status, http_client.MOVED_PERMANENTLY)
+            self.ae(r.status, http.client.MOVED_PERMANENTLY)
             self.ae(r.getheader('Location'), '/somewhere-else')
             self.ae(b'', r.read())
 
@@ -223,63 +222,63 @@ class TestHTTP(BaseTest):
             # Test simple GET
             conn.request('GET', '/test/')
             r = conn.getresponse()
-            self.ae(r.status, http_client.OK)
+            self.ae(r.status, http.client.OK)
             self.ae(r.read(), b'test')
 
             # Test TRACE
             lines = ['TRACE /xxx HTTP/1.1', 'Test: value', 'Xyz: abc, def', '', '']
             r = raw_send(conn, ('\r\n'.join(lines)).encode('ascii'))
-            self.ae(r.status, http_client.OK)
+            self.ae(r.status, http.client.OK)
             self.ae(r.read().decode('utf-8'), '\n'.join(lines[:-2]))
 
             # Test POST with simple body
             conn.request('POST', '/test', 'body')
             r = conn.getresponse()
-            self.ae(r.status, http_client.OK)
+            self.ae(r.status, http.client.OK)
             self.ae(r.read(), b'testbody')
 
             # Test POST with chunked transfer encoding
             conn.request('POST', '/test', headers={'Transfer-Encoding': 'chunked'})
             conn.send(b'4\r\nbody\r\na\r\n1234567890\r\n0\r\n\r\n')
             r = conn.getresponse()
-            self.ae(r.status, http_client.OK)
+            self.ae(r.status, http.client.OK)
             self.ae(r.read(), b'testbody1234567890')
 
             conn.request('GET', '/test' + ('a' * 200))
             r = conn.getresponse()
-            self.ae(r.status, http_client.BAD_REQUEST)
+            self.ae(r.status, http.client.BAD_REQUEST)
 
             conn = server.connect()
             conn.request('GET', '/test', ('a' * 200))
             r = conn.getresponse()
-            self.ae(r.status, http_client.REQUEST_ENTITY_TOO_LARGE)
+            self.ae(r.status, http.client.REQUEST_ENTITY_TOO_LARGE)
 
             conn = server.connect()
             conn.request('POST', '/test', headers={'Transfer-Encoding': 'chunked'})
             conn.send(b'x\r\nbody\r\n0\r\n\r\n')
             r = conn.getresponse()
-            self.ae(r.status, http_client.BAD_REQUEST)
+            self.ae(r.status, http.client.BAD_REQUEST)
             self.assertIn(b'not a valid chunk size', r.read())
 
             conn.request('POST', '/test', headers={'Transfer-Encoding': 'chunked'})
             conn.send(b'4\r\nbody\r\n200\r\n\r\n')
             r = conn.getresponse()
-            self.ae(r.status, http_client.REQUEST_ENTITY_TOO_LARGE)
+            self.ae(r.status, http.client.REQUEST_ENTITY_TOO_LARGE)
             conn.request('POST', '/test', body='a'*200)
             r = conn.getresponse()
-            self.ae(r.status, http_client.REQUEST_ENTITY_TOO_LARGE)
+            self.ae(r.status, http.client.REQUEST_ENTITY_TOO_LARGE)
 
             conn = server.connect()
             conn.request('POST', '/test', headers={'Transfer-Encoding': 'chunked'})
             conn.send(b'3\r\nbody\r\n0\r\n\r\n')
             r = conn.getresponse()
-            self.ae(r.status, http_client.BAD_REQUEST), self.ae(r.read(), b'Chunk does not have trailing CRLF')
+            self.ae(r.status, http.client.BAD_REQUEST), self.ae(r.read(), b'Chunk does not have trailing CRLF')
 
             conn = server.connect(timeout=base_timeout * 5)
             conn.request('POST', '/test', headers={'Transfer-Encoding': 'chunked'})
             conn.send(b'30\r\nbody\r\n0\r\n\r\n')
             r = conn.getresponse()
-            self.ae(r.status, http_client.REQUEST_TIMEOUT)
+            self.ae(r.status, http.client.REQUEST_TIMEOUT)
             self.assertIn(b'', r.read())
 
             conn = server.connect()
@@ -321,12 +320,12 @@ class TestHTTP(BaseTest):
             conn = server.connect()
             conn.request('GET', '/an_etagged_path')
             r = conn.getresponse()
-            self.ae(r.status, http_client.OK), self.ae(r.read(), b'an_etagged_path')
+            self.ae(r.status, http.client.OK), self.ae(r.read(), b'an_etagged_path')
             etag = r.getheader('ETag')
             self.ae(etag, '"{}"'.format(hashlib.sha1(b'an_etagged_path').hexdigest()))
             conn.request('GET', '/an_etagged_path', headers={'If-None-Match':etag})
             r = conn.getresponse()
-            self.ae(r.status, http_client.NOT_MODIFIED)
+            self.ae(r.status, http.client.NOT_MODIFIED)
             self.ae(r.read(), b'')
 
             # Test gzip
@@ -336,7 +335,7 @@ class TestHTTP(BaseTest):
             conn.request('GET', '/an_etagged_path', headers={'Accept-Encoding':'gzip'})
             r = conn.getresponse()
             self.ae(str(len(raw)), r.getheader('Calibre-Uncompressed-Length'))
-            self.ae(r.status, http_client.OK), self.ae(zlib.decompress(r.read(), 16+zlib.MAX_WBITS), raw)
+            self.ae(r.status, http.client.OK), self.ae(zlib.decompress(r.read(), 16+zlib.MAX_WBITS), raw)
 
             # Test dynamic etagged content
             num_calls = [0]
@@ -348,13 +347,13 @@ class TestHTTP(BaseTest):
             conn = server.connect()
             conn.request('GET', '/an_etagged_path')
             r = conn.getresponse()
-            self.ae(r.status, http_client.OK), self.ae(r.read(), b'data')
+            self.ae(r.status, http.client.OK), self.ae(r.read(), b'data')
             etag = r.getheader('ETag')
             self.ae(etag, '"xxx"')
             self.ae(r.getheader('Content-Length'), '4')
             conn.request('GET', '/an_etagged_path', headers={'If-None-Match':etag})
             r = conn.getresponse()
-            self.ae(r.status, http_client.NOT_MODIFIED)
+            self.ae(r.status, http.client.NOT_MODIFIED)
             self.ae(r.read(), b'')
             self.ae(num_calls[0], 1)
 
@@ -370,11 +369,11 @@ class TestHTTP(BaseTest):
                 self.ae(r.getheader('Content-Type'), guess_type(f.name)[0])
                 self.ae(str(r.getheader('Accept-Ranges')), 'bytes')
                 self.ae(int(r.getheader('Content-Length')), len(fdata))
-                self.ae(r.status, http_client.OK), self.ae(r.read(), fdata)
+                self.ae(r.status, http.client.OK), self.ae(r.read(), fdata)
 
                 conn.request('GET', '/test', headers={'Range':'bytes=2-25'})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.PARTIAL_CONTENT)
+                self.ae(r.status, http.client.PARTIAL_CONTENT)
                 self.ae(str(r.getheader('Accept-Ranges')), 'bytes')
                 self.ae(str(r.getheader('Content-Range')), f'bytes 2-25/{len(fdata)}')
                 self.ae(int(r.getheader('Content-Length')), 24)
@@ -382,27 +381,27 @@ class TestHTTP(BaseTest):
 
                 conn.request('GET', '/test', headers={'Range':'bytes=100000-'})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.REQUESTED_RANGE_NOT_SATISFIABLE)
+                self.ae(r.status, http.client.REQUESTED_RANGE_NOT_SATISFIABLE)
                 self.ae(str(r.getheader('Content-Range')), f'bytes */{len(fdata)}')
 
                 conn.request('GET', '/test', headers={'Range':'bytes=25-50', 'If-Range':etag})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.PARTIAL_CONTENT), self.ae(r.read(), fdata[25:51])
+                self.ae(r.status, http.client.PARTIAL_CONTENT), self.ae(r.read(), fdata[25:51])
                 self.ae(int(r.getheader('Content-Length')), 26)
 
                 conn.request('GET', '/test', headers={'Range':'bytes=0-1000000'})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.PARTIAL_CONTENT), self.ae(r.read(), fdata)
+                self.ae(r.status, http.client.PARTIAL_CONTENT), self.ae(r.read(), fdata)
 
                 conn.request('GET', '/test', headers={'Range':'bytes=25-50', 'If-Range':'"nomatch"'})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.OK), self.ae(r.read(), fdata)
+                self.ae(r.status, http.client.OK), self.ae(r.read(), fdata)
                 self.assertFalse(r.getheader('Content-Range'))
                 self.ae(int(r.getheader('Content-Length')), len(fdata))
 
                 conn.request('GET', '/test', headers={'Range':'bytes=0-25,26-50'})
                 r = conn.getresponse()
-                self.ae(r.status, http_client.PARTIAL_CONTENT)
+                self.ae(r.status, http.client.PARTIAL_CONTENT)
                 clen = int(r.getheader('Content-Length'))
                 data = r.read()
                 self.ae(clen, len(data))
@@ -417,7 +416,7 @@ class TestHTTP(BaseTest):
                 conn = server.connect(timeout=1)
                 conn.request('GET', '/test')
                 r = conn.getresponse()
-                self.ae(r.status, http_client.OK)
+                self.ae(r.status, http.client.OK)
                 rdata = r.read()
                 self.ae(len(data), len(rdata))
                 self.ae(hashlib.sha1(data).hexdigest(), hashlib.sha1(rdata).hexdigest())
